#ifndef NT2_INCLUDE_FUNCTIONS_CUMTRAPZ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CUMTRAPZ_HPP_INCLUDED

#include <nt2/core/include/functions/cumtrapz.hpp>

#endif
